@@ -5,6 +5,7 @@ This package contains validation logic for schemas, contracts,
 protocols, and plans.
 """
 
+from specfact_cli.validators.agile_validation import AgileValidationError, AgileValidator
 from specfact_cli.validators.contract_validator import (
     ContractDensityMetrics,
     calculate_contract_density,
@@ -16,6 +17,8 @@ from specfact_cli.validators.schema import SchemaValidator, validate_plan_bundle
 
 
 __all__ = [
+    "AgileValidationError",
+    "AgileValidator",
     "ContractDensityMetrics",
     "FSMValidator",
     "ReproChecker",
